// Importing all the required packages
import {
  select,
  json,
  csv,
  geoPath,
  geoAlbersUsa,
  geoMercator,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';
import { feature, mesh } from 'topojson';

//  select() - selects only the DOM element defined in the given CSS selector
const svg = select('svg');

const projection = geoMercator()
  .translate([-1780, 1050])
  .scale([1600]);
const pathGenerator = geoPath().projection(projection);

const colorScale = scaleOrdinal(schemeCategory10);

//.json file which contains the India map data required to visualize. 
json(
  'https://gist.githubusercontent.com/Shivamaninaidu/b62d18f6202d6c5e068968b74d3f50a6/raw/1def2ec948a8725ef2d90f68ba6b532a0eeeb98c/india%2520map'
).then((data) => {
  const countryShapes = feature(
    data,
    data.objects.IND_adm1
  );
countryShapes.features.shift()
  
 // selectAll() - selects all the element that matches the specified selector string
  svg
    .selectAll('path')
    .data(countryShapes.features)
    .enter()
    .append('path')
    .attr('class', 'states')
    .attr('fill', (d) => colorScale(d.properties.NAME_1))
    .attr('d', (d) => pathGenerator(d))
    .append('title')
    .text((d) => d.properties.NAME_1);

svg
  .selectAll('text')
  .data(countryShapes.features)
  .enter()
  .append('text')
  .text((d) => d.properties.NAME_1)
  .attr('x', d=>  pathGenerator.centroid(d)[0]   )
  .attr('y',d=>pathGenerator.centroid(d)[1])
    .attr("text-anchor", "middle")
   .attr("font-size", "15px");
});